@@ -428,11 +428,6 @@ class Database(object):
     def set_statistics(self, table):
         """Calcula les estadístiques d'una taula d'Oracle."""
         pass
-        self.cursor = self.connection.cursor()
-        proc = 'DBMS_STATS.GATHER_TABLE_STATS'
-        self.cursor.callproc(proc, (self.user, table.upper()))
-        self.cursor.close()
-        self.connection.commit()
 
     def set_grants(self, grants, tables, users, inheritance=True):
         """Estableix grants."""
